# genomeview - a python module for visualizing genomic data

![genomeview example image](https://raw.githubusercontent.com/nspies/genomeview/master/docs/images/overview.svg?sanitize=true)

Example [jupyter notebook](http://nbviewer.jupyter.org/github/nspies/genomeview/blob/master/examples/bams.ipynb) with visualizations inline.

See the [documentation on read-the-docs](http://genomeview.readthedocs.io/en/latest/index.html) for installation and usage
